import { httpGet, httpPost } from '@/utils/http'

export interface TeamInfo {
  total?: number // 总人数 <int64>
  rewardsTotal?: number // 可领取奖励人数 <int64>
  teamACount?: number // 团队A人数 <int64>
  teamBCount?: number // 团队B人数 <int64>
  proportionA?: string // 团队A金币抽成占比
  proportionB?: string // 团队B金币抽成占比
  claimableRewardsA?: number // 团队A可领取奖励人数，默认值: 0 <int64>
  claimableRewardsB?: number // 团队B可领取奖励人数，默认值: 0 <int64>
  claimableAmountA?: number // 团队A可领取奖励金额，默认值: BigDecimal.ZERO
  claimableAmountB?: number // 团队B可领取奖励金额
}

export interface TeamUser {
  tgId?: string // tg小程序id
  tgAccount?: string // tg账号
  firstName?: string // 名
  lastName?: string // 姓
  nickname?: string // 昵称
  realName?: string // 真实姓名
  avatar?: string // 头像
  teamType?: string // 团队类型
  teamRewardAmount: number // 团队奖励金额
  userYieldTotal: number // 用户总收益
}

export interface TeamAOB {
  total: number
  users: TeamUser[]
}

export interface TeamInviteRewardsRule {
  inviteNum: number
  inviteRewardsRuleList: TeamInviteRewardsRules[]
}

export interface TeamInviteRewardsRules {
  id?: string // 主键 <int64>
  rewardsName?: string // 奖励名称
  rewardsDescribe?: string // 奖励说明
  inviteNum?: number // 邀请好友数量
  goldCoinNum?: number // 金币数量
  rewardsLevel?: number // 奖励层级
  createdBy?: number // 创建人 <int64>
  createdTime?: string // 创建时间
  updatedBy?: number // 更新人 <int64>
  updatedTime?: string // 更新时间
  percentage?: number
}

// 获取分享码
export const getShareCode = () => {
  return httpPost<string>('/app/distribution/getShareCode')
}
// 获取团队信息
export const getMyTeamsInfo = () => {
  return httpPost<TeamInfo>('/app/team/share/getMyTeamsInfo')
}
// 获取团队固定奖励列表
export const getTeamInviteRewardsList = () => {
  return httpPost<TeamInfo[]>('/app/team/share/getTeamInviteRewardsList')
}
// 收取团队固定奖励
export const claimTeamInviteReward = () => {
  return httpPost<TeamInfo[]>('/app/team/share/claimTeamInviteReward')
}

// 获取ab邀请信息
export const getTeamShareUserListByType = (type: 'A' | 'B') => {
  return httpPost<TeamAOB>('/app/team/share/getTeamShareUserListByType', { type })
}
// 获取ab邀请奖励
export const claimTeamShareReward = (type: 'A' | 'B') => {
  return httpPost<TeamAOB>('/app/team/share/claimTeamShareReward', { type })
}

// 获取阶段邀请列表
export const getTeamInviteRewardsRules = () => {
  return httpPost<TeamInviteRewardsRule>('/app/team/share/getTeamInviteRewardsRules')
}
// 获取阶段邀请奖励
export const claimTeamInviteTaskReward = (ruleId: string) => {
  return httpPost<TeamInviteRewardsRule>('/app/team/share/claimTeamInviteTaskReward', { ruleId })
}
